==> keybase-2.8.0.tar.gz: client-2.8.0/shared/profile/folders/index.js <==
// @flow
import * as React from 'react'
import * as Styles from '../../styles'
import * as Kb from '../../common-adapters'

export type TlfProps = {
  openInFilesTab: () => void,
  isPublic: boolean,
  isSelf: boolean,
  text: string,
}

const Tlf = (props: TlfProps) => (
  <Kb.ClickableBox onClick={props.openInFilesTab} style={styles.itemContainer}>
    <Kb.Icon
      type={props.isSelf ? 'iconfont-folder-public' /* has the little head */ : 'iconfont-folder-private'}
      color={props.isPublic ? Styles.globalColors.yellowGreen : Styles.globalColors.darkBlue}
    />
    <Kb.Text type="BodyPrimaryLink" style={styles.itemText}>
      {props.text}
    </Kb.Text>
  </Kb.ClickableBox>
)

export type Props = {
  tlfs: Array<TlfProps>,
  loadTlfs: () => void,
}

export type State = {
  expanded: boolean,
}

const numFoldersShown = 4

class Folders extends React.PureComponent<Props, State> {
  state = {
    expanded: false,
  }
  expand = () => this.setState({expanded: true})
  componentDidMount() {
    this.props.loadTlfs()
  }
  render() {
    return (
      <React.Fragment>
        {(this.state.expanded ? this.props.tlfs : this.props.tlfs.slice(0, numFoldersShown)).map(tlf => (
          <Tlf {...tlf} key={tlf.text} />
        ))}
        {!this.state.expanded &&
          this.props.tlfs.length > numFoldersShown && (
            <Kb.ClickableBox key="more" onClick={this.expand} style={styles.itemContainer}>
              <Kb.Icon type="iconfont-ellipsis" />
              <Kb.Text type="BodySmall" style={styles.itemText}>
                + {this.props.tlfs.length - numFoldersShown} more
              </Kb.Text>
            </Kb.ClickableBox>
          )}
      </React.Fragment>
    )
  }
}

const styles = Styles.styleSheetCreate({
  itemContainer: {
    ...Styles.globalStyles.flexBoxRow,
    alignItems: 'flex-start',
    paddingTop: 8,
    paddingBottom: 8,
  },
  itemText: Styles.platformStyles({
    common: {
      marginLeft: Styles.globalMargins.tiny,
      color: Styles.globalColors.black_60,
      overflow: 'hidden',
    },
    isElectron: {
      wordWrap: 'break-word',
    },
  }),
})

export default Folders

==> keybase-2.11.0.tar.gz: client-2.11.0/shared/profile/folders/index.js <==
// @flow
import * as React from 'react'
import * as Styles from '../../styles'
import * as Kb from '../../common-adapters'

export type TlfProps = {
  openInFilesTab: () => void,
  isPublic: boolean,
  isSelf: boolean,
  text: string,
}

const Tlf = (props: TlfProps) => (
  <Kb.ClickableBox onClick={props.openInFilesTab} style={styles.itemContainer}>
    <Kb.Icon
      type={props.isSelf ? 'iconfont-folder-public' /* has the little head */ : 'iconfont-folder-private'}
      color={props.isPublic ? Styles.globalColors.yellowGreen : Styles.globalColors.darkBlue}
    />
    <Kb.Text type="BodyPrimaryLink" style={styles.itemText}>
      {props.text}
    </Kb.Text>
  </Kb.ClickableBox>
)

export type Props = {
  tlfs: Array<TlfProps>,
  loadTlfs: () => void,
}

export type State = {
  expanded: boolean,
}

const numFoldersShown = 4

class Folders extends React.PureComponent<Props, State> {
  state = {
    expanded: false,
  }
  expand = () => this.setState({expanded: true})
  componentDidMount() {
    this.props.loadTlfs()
  }
  render() {
    return (
      <React.Fragment>
        {(this.state.expanded ? this.props.tlfs : this.props.tlfs.slice(0, numFoldersShown)).map(tlf => (
          <Tlf {...tlf} key={tlf.text} />
        ))}
        {!this.state.expanded && this.props.tlfs.length > numFoldersShown && (
          <Kb.ClickableBox key="more" onClick={this.expand} style={styles.itemContainer}>
            <Kb.Icon type="iconfont-ellipsis" />
            <Kb.Text type="BodySmall" style={styles.itemText}>
              + {this.props.tlfs.length - numFoldersShown} more
            </Kb.Text>
          </Kb.ClickableBox>
        )}
      </React.Fragment>
    )
  }
}

const styles = Styles.styleSheetCreate({
  itemContainer: {
    ...Styles.globalStyles.flexBoxRow,
    alignItems: 'flex-start',
    paddingTop: 8,
    paddingBottom: 8,
  },
  itemText: Styles.platformStyles({
    common: {
      marginLeft: Styles.globalMargins.tiny,
      color: Styles.globalColors.black_60,
      overflow: 'hidden',
    },
    isElectron: {
      wordWrap: 'break-word',
    },
  }),
})

export default Folders
